summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/nsc/plugins/Plugin.scala
diff options
context:
space:
mode:
authormichelou <michelou@epfl.ch>2011-09-13 18:50:08 +0000
committermichelou <michelou@epfl.ch>2011-09-13 18:50:08 +0000
commitac7152b8bb4ec81a44bd1964a282c20c55d16729 (patch)
treeca67ee4513656dcc7146c0c37110c77f969d2233 /src/compiler/scala/tools/nsc/plugins/Plugin.scala
parentacc4c04b0c29436d2328d0e31a26bf2be4b96117 (diff)
downloadscala-ac7152b8bb4ec81a44bd1964a282c20c55d16729.tar.gz
scala-ac7152b8bb4ec81a44bd1964a282c20c55d16729.tar.bz2
scala-ac7152b8bb4ec81a44bd1964a282c20c55d16729.zip
updated scaladoc comments, did some cleanup
Diffstat (limited to 'src/compiler/scala/tools/nsc/plugins/Plugin.scala')
-rw-r--r--src/compiler/scala/tools/nsc/plugins/Plugin.scala34
1 files changed, 18 insertions, 16 deletions
diff --git a/src/compiler/scala/tools/nsc/plugins/Plugin.scala b/src/compiler/scala/tools/nsc/plugins/Plugin.scala
index bfc1c2dbc2..99b4a3d6f3 100644
--- a/src/compiler/scala/tools/nsc/plugins/Plugin.scala
+++ b/src/compiler/scala/tools/nsc/plugins/Plugin.scala
@@ -13,17 +13,20 @@ import java.util.zip.ZipException
import scala.collection.mutable
import mutable.ListBuffer
+/*@XML*/
import scala.xml.XML
+/*XML@*/
+/*@NOXML
+import scala.tools.util.XML
+XMLNO@*/
-/** <p>
- * Information about a plugin loaded from a jar file.
- * </p>
- * <p>
- * The concrete subclass must have a one-argument constructor
- * that accepts an instance of <code>Global</code>.
- * </p><pre>
+/** Information about a plugin loaded from a jar file.
+ *
+ * The concrete subclass must have a one-argument constructor
+ * that accepts an instance of `global`.
+ * {{{
* (val global: Global)
- * </pre>
+ * }}}
*
* @author Lex Spoon
* @version 1.0, 2007-5-21
@@ -42,7 +45,7 @@ abstract class Plugin {
* to a constructor parameter in the concrete subclass. */
val global: Global
- /** Handle any plugin-specific options. The -P:plugname: part
+ /** Handle any plugin-specific options. The `-P:plugname:` part
* will not be present. */
def processOptions(options: List[String], error: String => Unit) {
if (!options.isEmpty)
@@ -50,9 +53,8 @@ abstract class Plugin {
}
/** A description of this plugin's options, suitable as a response
- * to the -help command-line option. Conventionally, the
- * options should be listed with the <code>-P:plugname:</code>
- * part included.
+ * to the -help command-line option. Conventionally, the options
+ * should be listed with the `-P:plugname:` part included.
*/
val optionsHelp: Option[String] = None
}
@@ -105,9 +107,9 @@ object Plugin {
type AnyClass = Class[_]
/** Loads a plugin class from the named jar file.
-
- * @return <code>None</code> if the jar file has no plugin in it or
- * if the plugin is badly formed.
+ *
+ * @return `None` if the jar file has no plugin in it or
+ * if the plugin is badly formed.
*/
def loadFrom(jarfile: Path, loader: ClassLoader): Option[AnyClass] =
loadDescription(jarfile) match {
@@ -124,7 +126,7 @@ object Plugin {
/** Load all plugins found in the argument list, both in the
* jar files explicitly listed, and in the jar files in the
- * directories specified. Skips all plugins in <code>ignoring</code>.
+ * directories specified. Skips all plugins in `ignoring`.
* A single classloader is created and used to load all of them.
*/
def loadAllFrom(